#
# spec file for package wdiff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wdiff
Version:        1.2.2
Release:        9.1
Summary:        Display Word Differences Between Text Files
License:        GPL-3.0-or-later
Group:          Productivity/Text/Utilities
URL:            https://www.gnu.org/software/wdiff/
Source0:        https://ftp.gnu.org/gnu/wdiff/wdiff-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/wdiff/wdiff-%{version}.tar.gz.sig
Source2:        %{name}.keyring
# build with gcc15
Patch0:         wdiff-gcc15.patch
BuildRequires:  help2man
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
wdiff compares two files and finds which words have been deleted or
added to old_file to get new_file. A word is considered to be anything
between whitespace.

Xwdiff is a handy X Window System front-end, based on Tcl/Tk.

%lang_package

%prep
%autosetup -p1

%build
%configure \
  --enable-experimental="mdiff wdiff2 unify"
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}-gnulib
%find_lang %{name}

%check
make %{?_smp_mflags} check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%license COPYING
%doc BACKLOG ChangeLog NEWS README* THANKS TODO ABOUT-NLS AUTHORS
%{_bindir}/mdiff
%{_bindir}/unify
%{_bindir}/wdiff
%{_bindir}/wdiff2
%{_infodir}/wdiff.info%{?ext_info}
%{_mandir}/man1/mdiff.1%{?ext_man}
%{_mandir}/man1/unify.1%{?ext_man}
%{_mandir}/man1/wdiff.1%{?ext_man}
%{_mandir}/man1/wdiff2.1%{?ext_man}

%files lang -f %{name}-gnulib.lang -f %{name}.lang

%changelog
* Wed Feb 19 2025 pgajdos@suse.com
- added patches
  fix build with gcc15
  + wdiff-gcc15.patch
* Thu Jan 13 2022 Ludwig Nussel <lnussel@suse.de>
- Do not recommend lang package. The lang package has automatic
  locale tags that make it autoinstall on systems with matching
  language setting.
* Wed Mar 31 2021 Stephan Kulow <coolo@suse.com>
- fix license to be GPL-3.0-or-later (see COPYING)
* Fri Jun  8 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Sat Mar 26 2016 mpluskal@suse.com
- Enable experimental tools (same as in Fedora)
  * mdiff
  * wdiff2
  * unify
- Enable internal testsuite
- Small spec file improvements and cleanups
* Tue May  5 2015 mpluskal@suse.com
- Update project and download url
* Tue May  5 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use macro for language package
- Add gpg signature
- Fix infor requirements
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 1.2.2:
  * Updated Vietnamese, Swedish, Estonian, Chinese (traditional),
    Brazilian Portuguese and Russian translations.
  * Updated gnulib.
  * Used more recent autotools: autoconf 2.69 and automake 1.14.1.
* Tue Mar 26 2013 pgajdos@suse.com
- updated to 1.2.1:
  * Added Esperanto translation.
  * Updated Czech, German, Spanish, Finnish, Galician, Italian, Dutch,
    Polish, Slovenian, Serbian, Swedish, Ukrainian and Vietnamese
    translations.
  * Updated gnulib.
  * Recreated build system using recent versions of autotools.
    This will avoid security issues in "make distcheck" target.
    (CVE-2012-3386)
* Tue Aug  7 2012 pgajdos@suse.com
- updated to 1.1.2:
  * Backport gnulib change to deal with removal of gets function.
    This is a build-time-only fix. (Mentioned in Fedora bug #821791)
  * Added Serbian translation.
  * Updated Danish and Vietnamese translations.
  * Work around a bug in the formatting of the man page.
    (Debian bug #669340)
  * Updated Czech, German, Spanish, Finnish, Dutch, Polish, Slovenian,
    Swedish and Ukrainian translations.
  * Fix several issue with the use of screen in the test suite.
  * Allow WDIFF_PAGER to override PAGER environment variable.
  * Do not autodetect less, so we don't auto-enable less-mode.
    This should improve things for UTF8 text. (Savannah bug #34224)
    Less-mode is considered deprecated, as it isn't fit for multi-byte
    encodings. Nevertheless it can still be enabled on the command line.
  * Introduces use of ngettext to allow correct handling of plural forms
* Tue Jul 17 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Mon Oct 31 2011 pgajdos@suse.com
- updated to 1.0.1:
  * Updated Polish, Ukrainian, Slovenian, Dutch, Finnish, Swedish and
    Czech translations
  * Changed major version to 1 to reflect maturity of the package
  * Updated Dutch, French, Danish and Slovenian translations
  * Added Ukrainian translation
  * Improved error reporting in case a child process has problems
  * Added tests to the test suite
  * Updated gnulib
* Tue May 24 2011 pgajdos@novell.com
- updated to 0.6.5:
  * Never initialize or deinitialize terminals, as we do no cursor
    movement
  * Deprecated --no-init-term (-K) command line option
  * Avoid relative path in man pages
  * Updated gnulib, might be particularly important for uClibc
    users
* Thu Nov 18 2010 pgajdos@suse.cz
- updated to 0.6.4:
  * Updated Catalan translations
  * Updated gnulib
* Tue Aug 24 2010 pgajdos@suse.cz
- update to 0.6.3:
  * `wdiff -d' to read input from single unified diff, perhaps stdin.
  * Updated texinfo documentation taking experimental switch into account.
  * Experimental programs (mdiff & friends) and a configure switch
  - -enable-experimental to control them.
  * Recent imports from gnulib, use of recent autotools.
  * Improved autodetection of termcap library like ncurses.
  * Reformatted translations, still a number of fuzzy translations.
  * Changed from CVS to bzr for source code version control.
  * Various bug fixes. See ChangeLog for a more exhaustive list.
  * Introduce --with-default-pager=PAGER configure switch.
  * Fix missing newline in info dir entry list.
  * Fix shell syntax in configure script
  * Updated gnulib and gettext, the latter to 0.18
  * Updated Dutch translation
  * Fixed a number of portability issues reported by maint.mk syntax checks
  * Updated Italian and Swedish translations
  * Updated gnulib
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Tue Aug  4 2009 jw@suse.de
- updated to GNU wdiff 0.5.93,
- removed upstreamed/opbsoleted patches,
- rediffed -c patch by Hans Lermen.
- added linenumbers to -c output
- added -A -B -U options to simplify -w -x -y -z settings
- added dummy -L option for compat with diff.
- documentation updated.
* Sun Feb 24 2008 crrodriguez@suse.de
- fix  file-not-in-lang warnings
* Sun Apr  1 2007 aj@suse.de
- Add ncurses-devel to BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 20 2004 ro@suse.de
- locale rename: no -> nb
* Mon Apr  5 2004 mjancar@suse.cz
- call diff with --normal (#34458)
* Fri Mar 26 2004 bk@suse.de
- build wdiff no longer static, saves space and helps bug #36829
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Feb 25 2003 vbobek@suse.cz
- Use %%install_info macro
* Tue Nov 12 2002 jderfina@suse.cz
- Removed multi-line strings from wdiff-0.5.2.dif.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Jan 23 2002 okir@suse.de
- fixed temp file race
* Wed May 23 2001 cihlar@suse.cz
- fixed includes
* Tue Mar 20 2001 cihlar@suse.cz
- fixed to compile on axp
* Wed Jan  3 2001 cihlar@suse.cz
- fixed wdiff --help
* Mon Nov 27 2000 cihlar@suse.cz
- fixed installation of xwdiff
* Mon Nov 20 2000 cihlar@suse.cz
- fixed copyright
- bzipped sources
- added suse_update_config
* Thu May 18 2000 cihlar@suse.cz
- upgrade to 0.5.2
* Tue Apr 11 2000 cihlar@suse.cz
- added BuildRoot
- removed Makefile.Linux
* Tue Jan 25 2000 ro@suse.de
- move info,man to usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  3 1998 ro@suse.de
- catch strstr-macro for glibc
* Tue Aug 11 1998 ke@suse.de
- add Hans Lermen's xwdiff, a Tcl/Tk based frontend.
* Tue Jul  7 1998 ro@suse.de
- added patches from gnu.utils.bug (mainly don't fclose(NULL))
* Fri Jun 19 1998 ro@suse.de
- added patches from hans lermen
* Fri Jun 19 1998 ro@suse.de
- initial package using diff from jurix mirror
